"use strict";
/**
 * This file is part of the ego-cli distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * ego-cli is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * ego-cli is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.EgoCommand = void 0;
const isRoot = require('is-root');
const contracts_1 = require("../../contracts");
const util_1 = require("../../util");
/**
 * Aptdate command.
 */
class EgoCommand extends contracts_1.CommandBase {
    constructor() {
        super(...arguments);
        /** @inheritdoc */
        this.description = "Runs 'apt-get update', 'apt-get upgrade' and 'apt-get autoremove' in one command.";
    }
    /** @inheritdoc */
    async execute(ctx) {
        if ('linux' !== process.platform) {
            console.warn("You only can run the command with linux and 'apt-get'!");
            ctx.exit(1);
        }
        if (!isRoot()) {
            console.warn("You require root privileges (sudo)!");
            ctx.exit(3);
        }
        await util_1.withSpinnerAsync(`Checking for 'apt-get' ...`, async (spinner) => {
            try {
                await util_1.spawnAsync('apt-get', ['-v'], {
                    cwd: ctx.cwd,
                    stdio: util_1.getSTDIO(ctx),
                });
                spinner.text = `'apt-get' is installed`;
            }
            catch (_a) {
                spinner.warn(`'apt-get' is NOT installed`);
                ctx.exit(2);
            }
        });
        // apt-get update
        await util_1.withSpinnerAsync(`Executing 'apt-get -y update' ...`, async (spinner) => {
            await util_1.spawnAsync('apt-get', ['-y', 'update'], {
                cwd: ctx.cwd,
                stdio: util_1.getSTDIO(ctx),
            });
            spinner.text = `'apt-get -y update' executed`;
        });
        // apt-get upgrade
        await util_1.withSpinnerAsync(`Executing 'apt-get -y upgrade' ...`, async (spinner) => {
            await util_1.spawnAsync('apt-get', ['-y', 'upgrade'], {
                cwd: ctx.cwd,
                stdio: util_1.getSTDIO(ctx),
            });
            spinner.text = `'apt-get -y upgrade' executed`;
        });
        // apt-get autoremove
        await util_1.withSpinnerAsync(`Executing 'apt-get -y autoremove' ...`, async (spinner) => {
            await util_1.spawnAsync('apt-get', ['-y', 'autoremove'], {
                cwd: ctx.cwd,
                stdio: util_1.getSTDIO(ctx),
            });
            spinner.text = `'apt-get -y autoremove' executed`;
        });
    }
    /** @inheritdoc */
    async showHelp() {
        util_1.writeLine(`Options:`);
        util_1.writeLine(` -v, --verbose  # Verbose output.`);
        util_1.writeLine();
        util_1.writeLine(`Example:  sudo ego aptdate`);
    }
}
exports.EgoCommand = EgoCommand;
//# sourceMappingURL=index.js.map