"use strict";
/**
 * This file is part of the ego-cli distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * ego-cli is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * ego-cli is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.EgoCommand = void 0;
const moment = require("moment");
require("moment-timezone");
const contracts_1 = require("../../contracts");
const util_1 = require("../../util");
/**
 * Clock command
 */
class EgoCommand extends contracts_1.CommandBase {
    constructor() {
        super(...arguments);
        /** @inheritdoc */
        this.description = `Shows the current time or a clock value of another timezone`;
        /** @inheritdoc */
        this.syntax = '[FROM-CLOCK?] [TO-TIMEZONE?] [FROM-TIMEZONE?] [options]';
    }
    /** @inheritdoc */
    async execute(ctx) {
        var _a;
        // output format
        let outputFormat = '';
        if (ctx.args['f']) {
            outputFormat = util_1.toStringSafe(ctx.args['f']).trim();
        }
        else if (ctx.args['format']) {
            outputFormat = util_1.toStringSafe(ctx.args['format']).trim();
        }
        outputFormat = util_1.toStringSafe(outputFormat).trim();
        if (outputFormat === '') {
            outputFormat = 'HH:mm:ss';
        }
        const outputValue = (input) => {
            util_1.write(input.format(outputFormat));
        };
        if (!((_a = ctx.args._) === null || _a === void 0 ? void 0 : _a.length)) {
            // output current time (UTC)
            outputValue(moment.utc());
        }
        else if (ctx.args._.length > 0) {
            // target timezone
            let targetTZ;
            if (ctx.args._.length > 1) {
                targetTZ = ctx.args._[1].trim();
            }
            targetTZ = util_1.toStringSafe(targetTZ).trim();
            if (targetTZ === '') {
                targetTZ = 'UTC';
            }
            // from timezone
            let fromTZ;
            if (ctx.args._.length > 2) {
                fromTZ = ctx.args._[2].trim();
            }
            fromTZ = util_1.toStringSafe(fromTZ).trim();
            if (fromTZ === '') {
                fromTZ = null;
            }
            // input value
            let value = ctx.args._[0].trim();
            if (value === '') {
                value = moment.utc().format('HH:mm:ss');
            }
            const from = fromTZ ? moment.tz(value, 'HH:mm:ss', fromTZ) : moment(value, 'HH:mm:ss');
            if (!from.isValid()) {
                console.warn('Invalid input value. Please you a value like 13:45:51');
                ctx.exit(1);
                return;
            }
            const to = moment.tz(from, targetTZ);
            outputValue(to);
        }
    }
    /** @inheritdoc */
    async showHelp() {
        util_1.writeLine(`Examples:  ego clock`);
        util_1.writeLine(`           ego clock 21:50`);
        util_1.writeLine(`           ego clock 21:50 --format="HH:mm"`);
        util_1.writeLine(`           ego clock 21:50 "America/New_York"`);
        util_1.writeLine(`           ego clock 21:50 "America/New_York" "UTC"`);
    }
}
exports.EgoCommand = EgoCommand;
//# sourceMappingURL=index.js.map