"use strict";
/**
 * This file is part of the ego-cli distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * ego-cli is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * ego-cli is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.EgoCommand = void 0;
const got_1 = require("got");
const contracts_1 = require("../../contracts");
const util_1 = require("../../util");
/**
 * Create command
 */
class EgoCommand extends contracts_1.CommandBase {
    constructor() {
        super(...arguments);
        /** @inheritdoc */
        this.description = `Runs an ${util_1.eGO('e.GO')} creator module on npm`;
        /** @inheritdoc */
        this.syntax = 'MODULE_NAME [ARGS*]';
    }
    /** @inheritdoc */
    async execute(ctx) {
        const MODULE_NAME = util_1.toStringSafe(ctx.args['_'][0])
            .toLowerCase()
            .trim();
        if ('' === MODULE_NAME) {
            console.warn('Please define the module name, you would like to execute!');
            ctx.exit(1);
        }
        const EGO_MODULE_NAME = `@egodigital/create-${MODULE_NAME}`;
        const ALTERNATIVE_NAME = `create-${MODULE_NAME}`;
        let moduleToExecute = EGO_MODULE_NAME;
        await util_1.withSpinnerAsync(`Checking for module '${EGO_MODULE_NAME}' ...`, async (spinner) => {
            const RESPONSE = await got_1.default.get(`https://registry.npmjs.org/${EGO_MODULE_NAME}`, {
                throwHttpErrors: false
            });
            switch (RESPONSE.statusCode) {
                case 200:
                    spinner.succeed(`Found module '${EGO_MODULE_NAME}'.`);
                    break;
                case 404:
                    moduleToExecute = ALTERNATIVE_NAME;
                    spinner.warn(`Did not find module '${EGO_MODULE_NAME}', try ${ALTERNATIVE_NAME}...`);
                    break;
                default:
                    spinner.fail(`Unexpected response '${RESPONSE.statusCode}': ${RESPONSE.body}`);
                    ctx.exit(2);
                    break;
            }
        });
        const MODULE_ARGS = [
            moduleToExecute
        ].concat(ctx.rawArgs.slice(1));
        util_1.spawn('npx', MODULE_ARGS, {
            stdio: 'inherit'
        });
    }
    /** @inheritdoc */
    async showHelp() {
        util_1.writeLine(`Examples:  ego create react-app my-web-app`);
        util_1.writeLine(`           ego create react-app-native my-mobile-app --template typescript`);
    }
}
exports.EgoCommand = EgoCommand;
//# sourceMappingURL=index.js.map