"use strict";
/**
 * This file is part of the ego-cli distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * ego-cli is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * ego-cli is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.EgoCommand = void 0;
const contracts_1 = require("../../contracts");
const docker_1 = require("../../docker");
const util_1 = require("../../util");
/**
 * Docker-Stop command.
 */
class EgoCommand extends contracts_1.CommandBase {
    constructor() {
        super(...arguments);
        /** @inheritdoc */
        this.description = "Stops all running Docker containers.";
    }
    /** @inheritdoc */
    async execute(ctx) {
        let containers;
        await util_1.withSpinnerAsync('Loading Docker containers ...', async (spinner) => {
            containers = docker_1.getRunningDockerContainers({
                cwd: ctx.cwd,
                verbose: ctx.verbose,
            });
            spinner.text = containers.length + ' Docker container(s) found';
        });
        for (let i = 0; i < containers.length; i++) {
            const C = containers[i];
            await util_1.withSpinnerAsync(`Stopping '${C}' (${i + 1} / ${containers.length}) ...`, async (spinner) => {
                await util_1.spawnAsync('docker', ['stop', C], {
                    cwd: ctx.cwd,
                    stdio: util_1.getSTDIO(ctx),
                });
                spinner.text = `'${C}' stopped (${i + 1} / ${containers.length})`;
            });
        }
    }
    /** @inheritdoc */
    async showHelp() {
        util_1.writeLine(`Options:`);
        util_1.writeLine(` -v, --verbose  # Verbose output.`);
        util_1.writeLine();
        util_1.writeLine(`Example:  ego docker-stop`);
    }
}
exports.EgoCommand = EgoCommand;
//# sourceMappingURL=index.js.map