"use strict";
/**
 * This file is part of the ego-cli distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * ego-cli is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * ego-cli is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.EgoCommand = void 0;
const contracts_1 = require("../../contracts");
const git_1 = require("../../git");
const util_1 = require("../../util");
/**
 * Git-Pull command.
 */
class EgoCommand extends contracts_1.CommandBase {
    constructor() {
        super(...arguments);
        /** @inheritdoc */
        this.description = 'Pulls from all remotes to the current branch.';
    }
    /** @inheritdoc */
    async execute(ctx) {
        let branch;
        await util_1.withSpinnerAsync('Detecting current branch ...', async (spinner) => {
            branch = git_1.getCurrentGitBranch({
                cwd: ctx.cwd,
                verbose: ctx.verbose,
            });
            spinner.text = `Branch: '${branch}'`;
        });
        let remotes;
        await util_1.withSpinnerAsync('Loading remotes ...', async (spinner) => {
            remotes = git_1.getGitRemotes({
                cwd: ctx.cwd,
                verbose: ctx.verbose,
            });
            spinner.text = remotes.length + ' remote(s) found';
        });
        for (let i = 0; i < remotes.length; i++) {
            const R = remotes[i];
            await util_1.withSpinnerAsync(`Pulling from '${R}' (${i + 1} / ${remotes.length}) ...`, async (spinner) => {
                await util_1.spawnAsync('git', ['pull', R, branch], {
                    cwd: ctx.cwd,
                    stdio: util_1.getSTDIO(ctx),
                });
                spinner.text = `Pulled from '${R}' (${i + 1} / ${remotes.length})`;
            });
        }
    }
    /** @inheritdoc */
    async showHelp() {
        util_1.writeLine(`Options:`);
        util_1.writeLine(` -v, --verbose  # Verbose output.`);
        util_1.writeLine();
        util_1.writeLine(`Example:  ego git-pull`);
    }
}
exports.EgoCommand = EgoCommand;
//# sourceMappingURL=index.js.map