"use strict";
/**
 * This file is part of the ego-cli distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * ego-cli is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * ego-cli is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.EgoCommand = void 0;
const contracts_1 = require("../../contracts");
const util_1 = require("../../util");
const publicIp = require("public-ip");
/**
 * Public-Ip command
 */
class EgoCommand extends contracts_1.CommandBase {
    constructor() {
        super(...arguments);
        /** @inheritdoc */
        this.description = 'Print public ipv4 and ipv6 ip address.';
        /** @inheritdoc */
        this.syntax = '[options]';
    }
    /** @inheritdoc */
    async execute(context) {
        await util_1.withSpinnerAsync(`Querying IPv4 from 'icanhazip.com' service...`, async (spinner) => {
            try {
                let ipv4 = await publicIp.v4({ onlyHttps: true });
                spinner.text = `IPv4: ${ipv4}`;
            }
            catch (error) {
                spinner.fail(`No ipv4 address found. (Error: ${error.message})`);
            }
        });
        await util_1.withSpinnerAsync(`Querying IPv6 from 'icanhazip.com' service...`, async (spinner) => {
            try {
                let ipv6 = await publicIp.v6({ onlyHttps: true });
                spinner.text = `IPv6: ${ipv6}`;
            }
            catch (error) {
                spinner.fail(`No ipv6 address found. (Error: ${error.message}`);
            }
        });
    }
    /** @inheritdoc */
    async showHelp() {
        util_1.writeLine(`Example:    ego public-ip`);
    }
}
exports.EgoCommand = EgoCommand;
//# sourceMappingURL=index.js.map