"use strict";
/**
 * This file is part of the ego-cli distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * ego-cli is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * ego-cli is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.EgoCommand = void 0;
const _ = require("lodash");
const fs = require("fs-extra");
const path = require("path");
const contracts_1 = require("../../contracts");
const storage_1 = require("../../storage");
const util_1 = require("../../util");
/**
 * Set command.
 */
class EgoCommand extends contracts_1.CommandBase {
    constructor() {
        super(...arguments);
        /** @inheritdoc */
        this.description = "Sets a config value.";
        /** @inheritdoc */
        this.syntax = 'NAME [VALUE*]';
    }
    /** @inheritdoc */
    async execute(ctx) {
        await ctx.queue.add(async () => {
            const CONFIG_NAME = storage_1.normalizeStorageKey(ctx.args['_'][0]);
            if ('' === CONFIG_NAME) {
                console.warn('No config name defined!');
                ctx.exit(1);
            }
            const GLOBAL = ctx.args['g'] || ctx.args['global'];
            let configValue = undefined;
            if (ctx.args['_'].length > 1) {
                const ALL_VALUES = ctx.args['_'].slice(1);
                if (1 === ALL_VALUES.length) {
                    configValue = ALL_VALUES[0];
                }
                else {
                    configValue = ALL_VALUES;
                }
            }
            let storageFilePath = false;
            if (!GLOBAL) {
                const LOCAL_EGO_DIR = ctx.getFullPath(contracts_1.EGO_FOLDER);
                if (fs.existsSync(LOCAL_EGO_DIR)) {
                    const STAT = fs.statSync(LOCAL_EGO_DIR);
                    if (STAT.isDirectory()) {
                        storageFilePath = path.resolve(path.join(LOCAL_EGO_DIR, contracts_1.STORAGE_FILE));
                    }
                }
            }
            if (false === storageFilePath) {
                storageFilePath = storage_1.getStorageFile();
            }
            let storage;
            if (fs.existsSync(storageFilePath)) {
                storage = JSON.parse(fs.readFileSync(storageFilePath, 'utf8'));
            }
            if (!_.isObjectLike(storage)) {
                storage = {};
            }
            if (_.isUndefined(configValue)) {
                delete storage[CONFIG_NAME];
            }
            else {
                storage[CONFIG_NAME] = configValue;
            }
            fs.writeFileSync(storageFilePath, JSON.stringify(storage, null, 2), 'utf8');
        });
    }
    /** @inheritdoc */
    async showHelp() {
        util_1.writeLine(`Options:`);
        util_1.writeLine(` -g, --global  # Sets the value globally.`);
        util_1.writeLine();
        util_1.writeLine(`Examples:  ego set email tanja.m@e-go-digital.com`);
        util_1.writeLine(`           ego set email marcel.k@e-go-digital.com --global`);
        util_1.writeLine(`           ego set email`);
    }
}
exports.EgoCommand = EgoCommand;
//# sourceMappingURL=index.js.map