"use strict";
/**
 * This file is part of the ego-cli distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * ego-cli is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * ego-cli is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRunningDockerContainers = void 0;
const _ = require("lodash");
const util_1 = require("./util");
/**
 * Lists the IDs of all running docker containers.
 *
 * @param {GetRunningDockerContainers} [opts] Custom options.
 *
 * @return {string[]} The list of running docker container IDs.
 */
function getRunningDockerContainers(opts) {
    if (_.isNil(opts)) {
        opts = {};
    }
    return util_1.asArray(util_1.spawn('docker', ['ps', '--format', '{{.ID}}'], {
        cwd: util_1.getCWD(opts),
        stdio: null,
    }).output).map((x) => {
        return util_1.toStringSafe(x)
            .split('\n');
    }).reduce((x, y) => {
        return x.concat(y);
    }, []).map(b => b.trim())
        .filter(b => '' !== b);
}
exports.getRunningDockerContainers = getRunningDockerContainers;
//# sourceMappingURL=docker.js.map