"use strict";
/**
 * This file is part of the ego-cli distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * ego-cli is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * ego-cli is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createHttpServer = void 0;
const express = require("express");
const fs = require("fs-extra");
const http = require("http");
const https = require("https");
const path = require("path");
const util_1 = require("./util");
/**
 * Creates a new HTTP server instance.
 *
 * @param {CreateHttpServerOptions} [opts] Custom options.
 *
 * @return {CreateHttpServerResult} The result.
 */
function createHttpServer(opts) {
    if (!opts) {
        opts = {};
    }
    let isHTTPs;
    let server = false;
    const app = express();
    if (!opts.forceHttp) {
        const EGO_FOLDER = util_1.getEGOFolder();
        const CERT_FILE = path.resolve(path.join(EGO_FOLDER, 'server.cert'));
        const KEY_FILE = path.resolve(path.join(EGO_FOLDER, 'server.key'));
        if (fs.existsSync(CERT_FILE) && fs.existsSync(KEY_FILE)) {
            isHTTPs = true;
            server = https.createServer({
                cert: fs.readFileSync(CERT_FILE),
                key: fs.readFileSync(KEY_FILE),
            }, app);
        }
    }
    if (false === server) {
        isHTTPs = false;
        server = http.createServer(app);
    }
    return {
        app,
        https: isHTTPs,
        server,
    };
}
exports.createHttpServer = createHttpServer;
//# sourceMappingURL=http.js.map