"use strict";
/**
 * This file is part of the ego-cli distribution.
 * Copyright (c) e.GO Digital GmbH, Aachen, Germany (https://www.e-go-digital.com/)
 *
 * ego-cli is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, version 3.
 *
 * ego-cli is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getShellScriptExtension = exports.executeShellScriptCommand = void 0;
const fs = require("fs-extra");
const os = require("os");
const path = require("path");
const sanitizeFilename = require('sanitize-filename');
const util_1 = require("./util");
/**
 * Tries to executes a command as bash script.
 *
 * @param {any} commandName The name of the command.
 * @param {any[]} args The list of arguments for the script.
 *
 * @return {boolean} A shell script has been executed or not.
 */
function executeShellScriptCommand(commandName, args) {
    commandName = sanitizeFilename(util_1.toStringSafe(commandName)
        .trim());
    if ('' !== commandName) {
        // ${HOME_DIR}/.ego/${commandName}.${scriptExt}
        const SCRIPT_FILE = path.resolve(path.join(os.homedir(), '.ego', commandName + getShellScriptExtension()));
        if (fs.existsSync(SCRIPT_FILE)) {
            const STAT = fs.statSync(SCRIPT_FILE);
            if (STAT.isFile()) {
                util_1.spawn(SCRIPT_FILE, args, {
                    cwd: process.cwd(),
                    env: process.env,
                });
                return true;
            }
        }
    }
    return false;
}
exports.executeShellScriptCommand = executeShellScriptCommand;
/**
 * Returns the file extension for shell scripts for the current platform.
 *
 * @return {string} The extension.
 */
function getShellScriptExtension() {
    if ('win32' === process.platform) {
        return '.cmd';
    }
    return '.sh';
}
exports.getShellScriptExtension = getShellScriptExtension;
//# sourceMappingURL=scripts.js.map